#
# spec file for package libXaw
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libXaw
VCS: https://src.suse.de/SLFO-pool/libXaw#d48fd6abc918b29249c4eb3e44906993a34ae93cbb73329120e309a77fda3cd8
Version:        1.0.16
Release:        160000.1.3
Summary:        The X Athena Widget Set
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libXaw
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libXaw/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.12
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xt)

%description
The X Window System Athena widget set implements simple user
interfaces based upon the X Toolkit Intrinsics (Xt) library.

%package -n libXaw6
Summary:        The X Athena Widget Set
Group:          System/Libraries
%ifarch ppc64 s390x x86_64 sparc64
Provides:       libXaw6.so.6()(64bit)
%else
Provides:       libXaw6.so.6
%endif

%description -n libXaw6
The X Window System Athena widget set implements simple user
interfaces based upon the X Toolkit Intrinsics (Xt) library.

%package -n libXaw7
Summary:        The X Athena Widget Set
Group:          System/Libraries
%ifarch ppc64 s390x x86_64 sparc64
Provides:       libXaw7.so.7()(64bit)
%else
Provides:       libXaw7.so.7
%endif

%description -n libXaw7
The X Window System Athena widget set implements simple user
interfaces based upon the X Toolkit Intrinsics (Xt) library.

%package -n libXaw8
Summary:        The X Athena Widget Set
Group:          System/Libraries
Requires:       libXaw7 = %version
%ifarch ppc64 s390x x86_64 sparc64
Provides:       libXaw.so.8()(64bit)
Provides:       libXaw8.so.8()(64bit)
%else
Provides:       libXaw.so.8
Provides:       libXaw8.so.8
%endif

%description -n libXaw8
The X Window System Athena widget set implements simple user
interfaces based upon the X Toolkit Intrinsics (Xt) library.

%package devel
Summary:        Development files for the X Athena Widget Set
Group:          Development/Libraries/C and C++
Requires:       libXaw6 = %version
Requires:       libXaw7 = %version
Requires:       libXaw8 = %version

%description devel
The X Window System Athena widget set implements simple user
interfaces based upon the X Toolkit Intrinsics (Xt) library.

This package contains the development headers for the library found
in libXaw6/libXaw7/libXaw8.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
b="%buildroot";
make install DESTDIR="$b"
rm -f "$b/%_libdir"/*.la

# For compatibility reasons
ln -s libXaw7.so.7 "$b/%_libdir/libXaw8.so.8";
ln -s libXaw.so.7 "$b/%_libdir/libXaw.so.8";

%post -n libXaw6 -p /sbin/ldconfig

%postun -n libXaw6 -p /sbin/ldconfig

%post -n libXaw7 -p /sbin/ldconfig

%postun -n libXaw7 -p /sbin/ldconfig

%post -n libXaw8 -p /sbin/ldconfig

%postun -n libXaw8 -p /sbin/ldconfig

%files -n libXaw6
%defattr(-,root,root)
%_libdir/libXaw6.so.6*
%_libdir/libXaw.so.6*

%files -n libXaw7
%defattr(-,root,root)
%_libdir/libXaw7.so.7*
%_libdir/libXaw.so.7*

%files -n libXaw8
%defattr(-,root,root)
%_libdir/libXaw8.so.8*
%_libdir/libXaw.so.8*

%files devel
%defattr(-,root,root)
%_includedir/X11/Xaw
%_libdir/libXaw*.so
%_libdir/pkgconfig/xaw*.pc
%_mandir/man3/Xaw.3*
%_docdir/%name

%changelog
* Mon Mar 11 2024 sndirsch@suse.com
- Update to version 1.0.16
  * Code-cleanup and build-fixes ...
* Thu Mar 16 2023 sndirsch@suse.com
- Update to version 1.0.15
  * gitlab CI: add a basic build test
  * Fix spelling/wording issues
  * Stop memory leak in GetResourcePixmapPath()
  * Stop memory leak in error paths in XawTextSinkConvertPropertyList()
  * Remove "All rights reserved" from Oracle copyright notices
  * Add .git-blame-ignore-revs to hide whitespace commits from git blame
  * Replace calls to index() with strchr()
  * configure: Use LT_INIT from libtool 2 instead of deprecated AC_PROG_LIBTOOL
  * Fix ctype(3) users.
  * issue #6: fix typo in XawMax parameter in GetBlockBoundaries
* Tue Mar 30 2021 sndirsch@suse.com
- Update to version 1.0.14
  * bugfix release
- supersedes U_NULL-pointer-dereference-in-XawAsciiSinkInitialize.patch
* Thu Jun 21 2018 msrb@suse.com
- U_NULL-pointer-dereference-in-XawAsciiSinkInitialize.patch
  * Fix crash when required font is not installed. (bsc#1098411)
* Mon May  4 2015 sndirsch@suse.com
- Update to version 1.0.13
  * Fix build with gcc -Werror=format-security
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Use autoconf HAVE_UNISTD_H instead of imake X_NOT_POSIX to find <unistd.h>
  * Just use C89 size_t instead of rolling our own Size_t
  * Use SEEK_* names instead of raw numbers for fseek whence argument
  * Makefile: use AM_V_GEN and AM_V_at to implement automake silent rules
  * Makefile: use $(LN_S) for better code portability
  * Include <unistd.h>
  * Fix abs() usage.
* Thu Sep 12 2013 zaitor@opensuse.org
- Update to version 1.0.12:
  + Replace TXT16 with XChar2b inline.
  + Remove CRAY/WORD64 support.
  + Fix fd leak when write() fails in WriteToFile().
  + Fix fd leak when fdopen() fails in InitStringOrFile().
  + Include winsock header on WIN32 to provide fd_set etc.
* Fri Jun 14 2013 jengelh@inai.de
- Add proper bit-type symbols for sparc64
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Wed Sep 19 2012 zaitor@opensuse.org
- Update to version 1.0.11:
  + Only call XawStackFree if XawStackAlloc was used for allocation
  + Correct order of arguments to XawStackFree()
  + Correct undefined behavior access to out of scope pointer
    contents
* Thu Apr 12 2012 vuntz@opensuse.org
- Update to version 1.0.10:
  + Fix potential infinte loop in XawBoxQueryGeometry()
  + Fixes for compiler warnings
  + General cleanups
  + Build configuration and documentation improvements
- Changes from version 1.0.9:
  + Fix build issues
  + Minor documentation cleanups
  + Build configuration improvements
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
